@@ -1,5 +1,5 @@
 package HTML::Links::Localize;
-$HTML::Links::Localize::VERSION = '0.2.9';
+$HTML::Links::Localize::VERSION = '0.2.10';
 use strict;
 use warnings;
 
@@ -302,7 +302,7 @@ HTML::Links::Localize - Convert HTML Files to be used on a hard disk
 
 =head1 VERSION
 
-version 0.2.9
+version 0.2.10
 
 =head1 SYNOPSIS
 
@@ -353,10 +353,6 @@ This function converts the entire directory tree that starts at the
 base directory. only-newer means to convert only files that are newer
 in a make-like fashion.
 
-=head1 VERSION
-
-version 0.2.9
-
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/>
@@ -376,11 +372,11 @@ is a BSD-style license. However, the correct license is the MIT X11.
 
 =head1 AUTHOR
 
-unknown
+Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by unknown.
+This software is Copyright (c) 2019 by Shlomi Fish.
 
 This is free software, licensed under:
 
@@ -389,7 +385,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/html-links-localize/issues>
+L<https://github.com/shlomif/perl-html-links-localize/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -498,8 +494,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/html-links-localize>
+L<https://github.com/shlomif/perl-html-links-localize>
 
-  git clone http://bitbucket.org/shlomif/perl-html-links-localize
+  git clone git://github.com/shlomif/perl-html-links-localize.git
 
 =cut
